==> fengoffice_1.7.5.zip: fengoffice/language/es_es/actions.php <==
<?php return array(
	'register' => 'Registrarse',
	'login' => 'Conexión',
	'logout' => 'Desconexión',
	'hide welcome info' => '» Ocultar información de forma permanente',
	'add company' => 'Añadir empresa',
	'edit company' => 'Editar datos de la empresa',
	'delete company' => 'Eliminar empresa',
	'edit company logo' => 'Guardar logo',
	'delete company logo' => 'Eliminar logo',
	'add client' => 'Añadir cliente',
	'edit client' => 'Editar cliente',
	'delete client' => 'Eliminar cliente',
	
	// Persons
	'add user' => 'Agregar Persona',
	'add user role' => 'Rol',
  	'add user action' => 'Agregar persona para usar tu Feng Office',
  	'add user button' => 'Agregar Persona',
  	'add user hide settings' => 'Ocultar todas las Configuaraciones para este Usuario',
  	'add user show settings' => 'Ver todas las Configuaraciones para este Usuario',
  	'add user show settings text' => 'Como esta persona va a usar el Feng Office, es posible que desee establecer los detalles específicos, como los permisos de acceso<br /> (limitado por defecto), zona horaria, la contraseña, la categoría de facturación, etc.',
  	'add user essential' => 'Información Escencial',
  	'add user essential text' => 'Esta es la única información obligatoria en este formulario. Después de hacer clic en "Añadir persona"<br /> la dirección de correo electrónico recibirán una invitación para unirse a su Feng Office.',
	'add user what does' => 'Qué hace esta Persona',
	'add user what does text' => 'Usted dirá mucho acerca de una persona mediante el establecimiento de la función y en qué compañía.<br />Al seleccionar una función de usuario se define como la persona que, básicamente, usar el Feng Office.',
	'add user others' => 'Acceso y Otras Configuraciones',
	'add user others text' => 'Establecer qué proyectos se esta persona pueda tener acceso. Establecer contraseñas, zona horaria, idioma y otras opciones de configuración del sistema.',
	'edit user' => 'Editar usuario',
	'delete user' => 'Eliminar usuario',
	'create user from contact' => 'Crear usuario a partir de un contacto existente',
	
	'add group' => 'Añadir grupo',
	'edit group' => 'Editar grupo',
	'delete group' => 'Eliminar grupo',
	'add project' => 'Añadir área de trabajo',
	'edit project' => 'Editar área de trabajo',
	'delete project' => 'Eliminar área de trabajo',
	'mark project as finished' => 'Marcar área de trabajo como cerrada',
	'mark project as active' => 'Marcar área de trabajo como activa',
	'add workspace' => 'Añadir nueva área de trabajo',
	'edit workspace' => 'Editar área de trabajo',
	'delete workspace' => 'Eliminar área de trabajo',
	'mark workspace as finished' => 'Marcar área de trabajo como finalizada',
	'mark workspace as active' => 'Marcar área de trabajo como activa',
	'add message' => 'Añadir nota',
	'edit message' => 'Editar nota',
	'delete message' => 'Eliminar nota',
	'view message' => 'Mostrar nota',
	'update message options' => 'Actializar opciones de nota',
	'subscribe to object' => 'Suscribirse al objeto',
	'unsubscribe from object' => 'Borrar suscripción al objeto',
	'add comment' => 'Añadir comentario',
	'edit comment' => 'Editar comentario',
	'add task list' => 'Añadir tarea',
	'edit task list' => 'Editar tarea',
	'delete task list' => 'Eliminar tarea',
	'reorder tasks' => 'Reordenar tareas',
	'reorder sub tasks' => 'Reordenar sub-tareas',
	'apply milestone to subtasks' => 'Aplicar Hito a Subtareas',
	'apply workspace to subtasks' => 'Aplicar Espacio de Trabajo a Subtareas',
	'copy task' => 'Copiar tarea',
	'copy milestone' => 'Copiar hito',
	'add task' => 'Añadir tarea',
	'add sub task' => 'Añadir subtarea',
	'edit task' => 'Editar tarea',
	'delete task' => 'Eliminar tarea',
	'mark task as completed' => 'Marcar tarea como completada',
	'mark task as open' => 'Marcar tarea como abierta',
	'add milestone' => 'Añadir hito',
	'edit milestone' => 'Editar hito',
	'delete milestone' => 'Eliminar hito',
	'add event' => 'Añadir evento',
	'edit event' => 'Editar evento',
	'delete event' => 'Eliminar evento',
	'previous month' => 'Mes anterior',
	'next month' => 'Próximo mes',
	'previous week' => 'Semana anterior',
	'next week' => 'Próxima semana',
	'previous day' => 'Día anterior',
	'next day' => 'Próximo día',
	'back to calendar' => 'Volver al calendario',
	'back to day' => 'Volver al día',
	'pick a date' => 'Elegir fecha',
	'month' => 'Mes',
	'week' => 'Semana',
	'can edit company data' => 'Permitir la edición de los datos de la empresa propietaria',
	'can manage security' => 'Permitir la modificación de las configuraciones de seguridad',
	'can manage workspaces' => 'Permitir la modificación de las configuraciones de áreas de trabajo',
	'can manage configuration' => 'Permitir la modificación de las configuraciones',
	'can manage contacts' => 'Permitirl la modificación de las configuraciones de todos los contactos',
	'group users' => 'Usuarios del grupo',
	'update people' => 'Modificar',
	'remove user from project' => 'Eliminar usuario de esta área de trabajo',
	'remove company from project' => 'Eliminar empresa de esta área de trabajo',
	'update profile' => 'Editar cuenta',
	'change password' => 'Modificar contraseña',
	'update avatar' => 'Guardar nueva imagen',
	'delete current avatar' => 'Eliminar la imagen actual',
	'add form' => 'Añadir formulario',
	'edit form' => 'Editar formulario',
	'delete form' => 'Eliminar formulario',
	'submit project form' => 'Enviar',
	'add file' => 'Añadir archivo',
	'file properties' => 'Propiedades del archivo',
	'upload file' => 'Cargar archivo',
	'create new revision' => 'Crear nueva revisión',
	'add document' => 'Añadir documento',
	'save document' => 'Guardar documento',
	'add spreadsheet' => 'Añadir hoja de cálculo',
	'add presentation' => 'Añadir presentación',
	'document' => 'Documento',
	'spreadsheet' => 'Hoja de cálculo',
	'presentation' => 'Presentación',
	'new' => 'Nuevo',
	'upload' => 'Cargar',
	'hide' => 'Ocultar',
	'new document' => 'Nuevo documento',
	'new spreadsheet' => 'Nueva hoja de cálculo',
	'new presentation' => 'Nueva presentación',
	'slideshow' => 'Presentación',
	'revisions and comments' => 'Revisiones y comentarios',
	'Save' => 'Guardar',
	'all elements' => 'Todos los elementos',
	'collapse all' => 'Contraer todos',
	'expand all' => 'Expandir todos',
	'properties' => 'Propiedades',
	'edit file' => 'Editar archivo',
	'edit document' => 'Editar documento',
	'edit spreadsheet' => 'Editar hoja de cálculo',
	'edit presentation' => 'Editar presentación',
	'play' => 'Reproducir',
	'queue' => 'Encolar',
	'delete file' => 'Eliminar archivo',
	'add folder' => 'Añadir carpeta',
	'edit folder' => 'Editar carpeta',
	'delete folder' => 'Eliminar carpeta',
	'edit file revisions' => 'Editar revisiones',
	'version' => 'ver',
	'last modification' => 'Última modificación',
	'link object' => 'Vincular este objeto',
	'link objects' => 'Vincular estos objetos',
	'link more objects' => 'Vincular a más objetos',
	'show all linked objects' => 'Mostrar todos ({0})',
	'unlink' => 'Eliminar vínculo',
	'unlink object' => 'Eliminar vínculo con este objeto',
	'unlink objects' => 'Eliminar vínculo con estos objetos',
	'extract' => 'Extraer',
	'add files to zip' => 'Añadir archivos',
	'delete tag' => 'Eliminar etiqueta',
	'update permissions' => 'Actualizar los permisos',
	'edit permissions' => 'Editar permisos',
	'edit permissions explanation' => 'Seleccione los usuarios habilitados para acceder al área de trabajo creada.',
	'save as new revision' => 'Guardar como nueva revisión',
	'save as' => 'Guardar como',
	'details' => 'Detalles',
	'view history for' => 'Ver historial',
	'view history' => 'Ver historial',
	'edit preferences' => 'Editar preferencias',
	'add new message' => 'Añadir nueva nota',
	'view milestone' => 'Ver hito',
	'custom properties' => 'Propiedades Personalizadas',
	'edit file properties' => 'Editar propiedades del archivo',
	'move to trash' => 'Enviar a la papelera',
	'restore from trash' => 'Restaurar de la papelera',
	'delete permanently' => 'Eliminar permanentemente',
	'copy file' => 'Copiar este archivo',
	'open weblink' => 'Abrir enlace web',
	'archive' => 'Archivar',
	'unarchive' => 'Desarchivar',
	'confirm archive selected objects' => '¿Está seguro que desea archivar los objetos seleccionados?',
	'confirm archive object' => '¿Está seguro que desea archivar este objeto?',
	'confirm unarchive object' => '¿Está seguro que desea desarchivar este objeto?',
	'report as spam' => 'Reportar como Spam',
	'not spam' => 'No es Spam',
	'mark as unread' => 'Marcar como no leído',
	'show' => 'Mostrar',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_es/actions.php <==
<?php return array(
	'register' => 'Registrarse',
	'login' => 'Conexión',
	'logout' => 'Desconexión',
	'hide welcome info' => '» Ocultar información de forma permanente',
	'add company' => 'Añadir empresa',
	'edit company' => 'Editar datos de la empresa',
	'delete company' => 'Eliminar empresa',
	'edit company logo' => 'Guardar logo',
	'delete company logo' => 'Eliminar logo',
	'add client' => 'Añadir cliente',
	'edit client' => 'Editar cliente',
	'delete client' => 'Eliminar cliente',
	'add user' => 'Añadir usuario',
	'edit user' => 'Editar usuario',
	'delete user' => 'Eliminar usuario',
	'create user from contact' => 'Crear usuario a partir del contacto',
	'add group' => 'Añadir grupo',
	'edit group' => 'Editar grupo',
	'delete group' => 'Eliminar grupo',
	'add project' => 'Añadir área de trabajo',
	'edit project' => 'Editar área de trabajo',
	'delete project' => 'Eliminar área de trabajo',
	'mark project as finished' => 'Marcar área de trabajo como cerrada',
	'mark project as active' => 'Marcar área de trabajo como activa',
	'add workspace' => 'Añadir nueva área de trabajo',
	'edit workspace' => 'Editar área de trabajo',
	'delete workspace' => 'Eliminar área de trabajo',
	'mark workspace as finished' => 'Marcar área de trabajo como finalizada',
	'mark workspace as active' => 'Marcar área de trabajo como activa',
	'add message' => 'Añadir nota',
	'edit message' => 'Editar nota',
	'delete message' => 'Eliminar nota',
	'view message' => 'Mostrar nota',
	'update message options' => 'Actializar opciones de nota',
	'subscribe to object' => 'Suscribirse al objeto',
	'unsubscribe from object' => 'Borrar subscripción al objeto',
	'add comment' => 'Añadir comentario',
	'edit comment' => 'Editar comentario',
	'add task list' => 'Añadir tarea',
	'edit task list' => 'Editar tarea',
	'delete task list' => 'Eliminar tarea',
	'reorder tasks' => 'Reordenar tareas',
	'reorder sub tasks' => 'Reordenar sub-tareas',
	'apply milestone to subtasks' => 'Aplicar Hito a Subtareas',
	'apply workspace to subtasks' => 'Aplicar Espacio de Trabajo a Subtareas',
	'copy task' => 'Copiar tarea',
	'copy milestone' => 'Copiar hito',
	'add task' => 'Añadir tarea',
	'add sub task' => 'Añadir subtarea',
	'edit task' => 'Editar tarea',
	'delete task' => 'Eliminar tarea',
	'mark task as completed' => 'Marcar tarea como completada',
	'mark task as open' => 'Marcar tarea como abierta',
	'add milestone' => 'Añadir hito',
	'edit milestone' => 'Editar hito',
	'delete milestone' => 'Eliminar hito',
	'add event' => 'Añadir evento',
	'edit event' => 'Editar evento',
	'delete event' => 'Eliminar evento',
	'previous month' => 'Mes anterior',
	'next month' => 'Próximo mes',
	'previous week' => 'Semana anterior',
	'next week' => 'Próxima semana',
	'previous day' => 'Día anterior',
	'next day' => 'Próximo día',
	'back to calendar' => 'Volver al calendario',
	'back to day' => 'Volver al día',
	'pick a date' => 'Elegir fecha',
	'month' => 'Mes',
	'week' => 'Semana',
	'can edit company data' => 'Permitir la edición de los datos de la empresa propietaria',
	'can manage security' => 'Permitir la modificación de las configuraciones de seguridad',
	'can manage workspaces' => 'Permitir la modificación de las configuraciones de áreas de trabajo',
	'can manage configuration' => 'Permitir la modificación de las configuraciones',
	'can manage contacts' => 'Permitirl la modificación de las configuraciones de todos los contactos',
	'group users' => 'Usuarios del grupo',
	'update people' => 'Modificar',
	'remove user from project' => 'Eliminar usuario de esta área de trabajo',
	'remove company from project' => 'Eliminar empresa de esta área de trabajo',
	'update profile' => 'Editar cuenta',
	'change password' => 'Modificar contraseña',
	'update avatar' => 'Guardar nueva imagen',
	'delete current avatar' => 'Eliminar la imagen actual',
	'add form' => 'Añadir formulario',
	'edit form' => 'Editar formulario',
	'delete form' => 'Eliminar formulario',
	'submit project form' => 'Enviar',
	'add file' => 'Añadir archivo',
	'file properties' => 'Propiedades del archivo',
	'upload file' => 'Cargar archivo',
	'create new revision' => 'Crear nueva revisión',
	'add document' => 'Añadir documento',
	'save document' => 'Guardar documento',
	'add spreadsheet' => 'Añadir hoja de cálculo',
	'add presentation' => 'Añadir presentación',
	'document' => 'Documento',
	'spreadsheet' => 'Hoja de cálculo',
	'presentation' => 'Presentación',
	'new' => 'Nuevo',
	'upload' => 'Cargar',
	'hide' => 'Ocultar',
	'new document' => 'Nuevo documento',
	'new spreadsheet' => 'Nueva hoja de cálculo',
	'new presentation' => 'Nueva presentación',
	'slideshow' => 'Presentación',
	'revisions and comments' => 'Revisiones y comentarios',
	'Save' => 'Guardar',
	'all elements' => 'Todos los elementos',
	'collapse all' => 'Contraer todos',
	'expand all' => 'Expandir todos',
	'properties' => 'Propiedades',
	'edit file' => 'Editar archivo',
	'edit document' => 'Editar documento',
	'edit spreadsheet' => 'Editar hoja de cálculo',
	'edit presentation' => 'Editar presentación',
	'play' => 'Reproducir',
	'queue' => 'Encolar',
	'delete file' => 'Eliminar archivo',
	'add folder' => 'Añadir carpeta',
	'edit folder' => 'Editar carpeta',
	'delete folder' => 'Eliminar carpeta',
	'edit file revisions' => 'Editar revisiones',
	'version' => 'ver',
	'last modification' => 'Última modificación',
	'link object' => 'Vincular este objeto',
	'link objects' => 'Vincular estos objetos',
	'link more objects' => 'Vincular a más objetos',
	'show all linked objects' => 'Mostrar todos ({0})',
	'unlink' => 'Eliminar vínculo',
	'unlink object' => 'Eliminar vínculo con este objeto',
	'unlink objects' => 'Eliminar vínculo con estos objetos',
	'extract' => 'Extraer',
	'add files to zip' => 'Añadir archivos',
	'delete tag' => 'Eliminar etiqueta',
	'update permissions' => 'Actualizar los permisos',
	'edit permissions' => 'Editar permisos',
	'edit permissions explanation' => 'Seleccione los usuarios habilitados para acceder al área de trabajo creada.',
	'save as new revision' => 'Guardar como nueva revisión',
	'save as' => 'Guardar como',
	'details' => 'Detalles',
	'view history for' => 'Ver historial',
	'view history' => 'Ver historial',
	'edit preferences' => 'Editar preferencias',
	'add new message' => 'Añadir nueva nota',
	'view milestone' => 'Ver hito',
	'custom properties' => 'Propiedades Personalizadas',
	'edit file properties' => 'Editar propiedades del archivo',
	'move to trash' => 'Enviar a la papelera',
	'restore from trash' => 'Restaurar de la papelera',
	'delete permanently' => 'Eliminar permanentemente',
	'copy file' => 'Copiar este archivo',
	'open weblink' => 'Abrir enlace web',
	'archive' => 'Archivar',
	'unarchive' => 'Desarchivar',
	'confirm archive selected objects' => '¿Está seguro que desea archivar los objetos seleccionados?',
	'confirm archive object' => '¿Está seguro que desea archivar este objeto?',
	'confirm unarchive object' => '¿Está seguro que desea desarchivar este objeto?',
	'report as spam' => 'Reportar como Spam',
	'not spam' => 'No es Spam',
	'mark as unread' => 'Marcar como no leído',
	'show' => 'Mostrar',
	'activate' => 'Activar',
	'disabled' => 'Desactivado',
); ?>
